@@ -1,7 +1,7 @@
 use super::{arc::ArcBuffer, number::Number};
 use std::{cmp::max, str::from_utf8_unchecked};
 
-#[pen_ffi_macro::any_conv(crate = "crate")]
+#[pen_ffi_macro::any(crate = "crate")]
 #[repr(C)]
 #[derive(Clone, Debug, Default)]
 pub struct ByteString {
